==> klayout_0.28.16.orig.tar.gz: klayout-0.28.16/scripts/mkqtdecl5/QtGui/allofqt.cpp <==
#include "QtGui/QAbstractTextDocumentLayout"
#include "QtGui/QAbstractUndoItem"
#include "QtGui/QAccessible"
#include "QtGui/QAccessibleActionInterface"
#include "QtGui/QAccessibleApplication"
#include "QtGui/QAccessibleBridge"
#include "QtGui/QAccessibleBridgePlugin"
#include "QtGui/QAccessibleEditableTextInterface"
#include "QtGui/QAccessibleEvent"
#include "QtGui/QAccessibleImageInterface"
#include "QtGui/QAccessibleInterface"
#include "QtGui/QAccessibleObject"
#include "QtGui/QAccessiblePlugin"
#include "QtGui/QAccessibleStateChangeEvent"
#include "QtGui/QAccessibleTableCellInterface"
#include "QtGui/QAccessibleTableInterface"
#include "QtGui/QAccessibleTableModelChangeEvent"
#include "QtGui/QAccessibleTextCursorEvent"
#include "QtGui/QAccessibleTextInsertEvent"
#include "QtGui/QAccessibleTextInterface"
#include "QtGui/QAccessibleTextRemoveEvent"
#include "QtGui/QAccessibleTextSelectionEvent"
#include "QtGui/QAccessibleTextUpdateEvent"
#include "QtGui/QAccessibleValueChangeEvent"
#include "QtGui/QAccessibleValueInterface"
#include "QtGui/QActionEvent"
#include "QtGui/QApplicationStateChangeEvent"
#include "QtGui/QBackingStore"
#include "QtGui/QBitmap"
#include "QtGui/QBrush"
#include "QtGui/QBrushData"
#include "QtGui/QClipboard"
#include "QtGui/QCloseEvent"
#include "QtGui/QColor"
#include "QtGui/QConicalGradient"
#include "QtGui/QContextMenuEvent"
#include "QtGui/QCursor"
#include "QtGui/QDesktopServices"
#include "QtGui/QDoubleValidator"
#include "QtGui/QDrag"
#include "QtGui/QDragEnterEvent"
#include "QtGui/QDragLeaveEvent"
#include "QtGui/QDragMoveEvent"
#include "QtGui/QDropEvent"
#include "QtGui/QEnterEvent"
#include "QtGui/QExposeEvent"
#include "QtGui/QFileOpenEvent"
#include "QtGui/QFocusEvent"
#include "QtGui/QFont"
#include "QtGui/QFontDatabase"
#include "QtGui/QFontInfo"
#include "QtGui/QFontMetrics"
#include "QtGui/QFontMetricsF"
#include "QtGui/QGenericMatrix"
#include "QtGui/QGenericPlugin"
#include "QtGui/QGenericPluginFactory"
#include "QtGui/QGlyphRun"
#include "QtGui/QGradient"
#include "QtGui/QGradientStop"
#include "QtGui/QGradientStops"
#include "QtGui/QGuiApplication"
#include "QtGui/QHelpEvent"
#include "QtGui/QHideEvent"
#include "QtGui/QHoverEvent"
#include "QtGui/QIcon"
#include "QtGui/QIconDragEvent"
#include "QtGui/QIconEngine"
#include "QtGui/QIconEnginePlugin"
#include "QtGui/QIconEngineV2"
#include "QtGui/QImage"
#include "QtGui/QImageCleanupFunction"
#include "QtGui/QImageIOHandler"
#include "QtGui/QImageIOPlugin"
#include "QtGui/QImageReader"
#include "QtGui/QImageTextKeyLang"
#include "QtGui/QImageWriter"
#include "QtGui/QInputEvent"
#include "QtGui/QInputMethod"
#include "QtGui/QInputMethodEvent"
#include "QtGui/QInputMethodQueryEvent"
#include "QtGui/QIntValidator"
#include "QtGui/QKeyEvent"
#include "QtGui/QKeySequence"
#include "QtGui/QLinearGradient"
#include "QtGui/QMatrix"
#include "QtGui/QMatrix2x2"
#include "QtGui/QMatrix2x3"
#include "QtGui/QMatrix2x4"
#include "QtGui/QMatrix3x2"
#include "QtGui/QMatrix3x3"
#include "QtGui/QMatrix3x4"
#include "QtGui/QMatrix4x2"
#include "QtGui/QMatrix4x3"
#include "QtGui/QMatrix4x4"
#include "QtGui/QMouseEvent"
#include "QtGui/QMoveEvent"
#include "QtGui/QMovie"
#include "QtGui/QNativeGestureEvent"
#include "QtGui/QOffscreenSurface"
#include "QtGui/QPagedPaintDevice"
#include "QtGui/QPageLayout"
#include "QtGui/QPageSize"
#include "QtGui/QPaintDevice"
#include "QtGui/QPaintDeviceWindow"
#include "QtGui/QPaintEngine"
#include "QtGui/QPaintEngineState"
#include "QtGui/QPainter"
#include "QtGui/QPainterPath"
#include "QtGui/QPainterPathStroker"
#include "QtGui/QPaintEvent"
#include "QtGui/QPalette"
#include "QtGui/QPdfWriter"
#include "QtGui/QPen"
#include "QtGui/QPicture"
#include "QtGui/QPictureFormatPlugin"
#include "QtGui/QPictureIO"
#include "QtGui/QPixelFormat"
#include "QtGui/QPixmap"
#include "QtGui/QPixmapCache"
#include "QtGui/QPlatformSurfaceEvent"
#include "QtGui/QPolygon"
#include "QtGui/QPolygonF"
#include "QtGui/QQuaternion"
#include "QtGui/QRadialGradient"
#include "QtGui/QRasterWindow"
#include "QtGui/QRawFont"
#include "QtGui/QRegExpValidator"
#include "QtGui/QRegion"
#include "QtGui/QRegularExpressionValidator"
#include "QtGui/QResizeEvent"
#include "QtGui/QRgb"
#include "QtGui/QScreen"
#include "QtGui/QScreenOrientationChangeEvent"
#include "QtGui/QScrollEvent"
#include "QtGui/QScrollPrepareEvent"
#include "QtGui/QSessionManager"
#include "QtGui/QShortcutEvent"
#include "QtGui/QShowEvent"
#include "QtGui/QStandardItem"
#include "QtGui/QStandardItemModel"
#include "QtGui/QStaticText"
#include "QtGui/QStatusTipEvent"
#include "QtGui/QStyleHints"
#include "QtGui/QSurface"
#include "QtGui/QSurfaceFormat"
#include "QtGui/QSyntaxHighlighter"
#include "QtGui/QTabletEvent"
#include "QtGui/QtEvents"
#include "QtGui/QTextBlock"
#include "QtGui/QTextBlockFormat"
#include "QtGui/QTextBlockGroup"
#include "QtGui/QTextBlockUserData"
#include "QtGui/QTextCharFormat"
#include "QtGui/QTextCursor"
#include "QtGui/QTextDocument"
#include "QtGui/QTextDocumentFragment"
#include "QtGui/QTextDocumentWriter"
#include "QtGui/QTextFormat"
#include "QtGui/QTextFragment"
#include "QtGui/QTextFrame"
#include "QtGui/QTextFrameFormat"
#include "QtGui/QTextFrameLayoutData"
#include "QtGui/QTextImageFormat"
#include "QtGui/QTextInlineObject"
#include "QtGui/QTextItem"
#include "QtGui/QTextLayout"
#include "QtGui/QTextLength"
#include "QtGui/QTextLine"
#include "QtGui/QTextList"
#include "QtGui/QTextListFormat"
#include "QtGui/QTextObject"
#include "QtGui/QTextObjectInterface"
#include "QtGui/QTextOption"
#include "QtGui/QTextTable"
#include "QtGui/QTextTableCell"
#include "QtGui/QTextTableCellFormat"
#include "QtGui/QTextTableFormat"
#include "QtGui/QtGui"
#include "QtGui/QtGuiDepends"
#include "QtGui/QtGuiVersion"
#include "QtGui/QToolBarChangeEvent"
#include "QtGui/QTouchDevice"
#include "QtGui/QTouchEvent"
#include "QtGui/QTransform"
#include "QtGui/QValidator"
#include "QtGui/QVector2D"
#include "QtGui/QVector3D"
#include "QtGui/QVector4D"
#include "QtGui/QWhatsThisClickedEvent"
#include "QtGui/QWheelEvent"
#include "QtGui/QWidgetList"
#include "QtGui/QWidgetMapper"
#include "QtGui/QWidgetSet"
#include "QtGui/QWindow"
#include "QtGui/QWindowList"
#include "QtGui/QWindowStateChangeEvent"

==> klayout_0.30.0.orig.tar.gz: klayout-0.30.0/scripts/mkqtdecl5/QtGui/allofqt.cpp <==
#include "QtGui/QAbstractTextDocumentLayout"
#include "QtGui/QAbstractUndoItem"
#include "QtGui/QAccessible"
#include "QtGui/QAccessibleActionInterface"
#include "QtGui/QAccessibleApplication"
#include "QtGui/QAccessibleBridge"
#include "QtGui/QAccessibleBridgePlugin"
#include "QtGui/QAccessibleEditableTextInterface"
#include "QtGui/QAccessibleEvent"
#include "QtGui/QAccessibleImageInterface"
#include "QtGui/QAccessibleInterface"
#include "QtGui/QAccessibleObject"
#include "QtGui/QAccessiblePlugin"
#include "QtGui/QAccessibleStateChangeEvent"
#include "QtGui/QAccessibleTableCellInterface"
#include "QtGui/QAccessibleTableInterface"
#include "QtGui/QAccessibleTableModelChangeEvent"
#include "QtGui/QAccessibleTextCursorEvent"
#include "QtGui/QAccessibleTextInsertEvent"
#include "QtGui/QAccessibleTextInterface"
#include "QtGui/QAccessibleTextRemoveEvent"
#include "QtGui/QAccessibleTextSelectionEvent"
#include "QtGui/QAccessibleTextUpdateEvent"
#include "QtGui/QAccessibleValueChangeEvent"
#include "QtGui/QAccessibleValueInterface"
#include "QtGui/QActionEvent"
#include "QtGui/QApplicationStateChangeEvent"
#include "QtGui/QBackingStore"
#include "QtGui/QBitmap"
#include "QtGui/QBrush"
#include "QtGui/QBrushData"
#include "QtGui/QClipboard"
#include "QtGui/QCloseEvent"
#include "QtGui/QColor"
#include "QtGui/QConicalGradient"
#include "QtGui/QContextMenuEvent"
#include "QtGui/QCursor"
#include "QtGui/QDesktopServices"
#include "QtGui/QDoubleValidator"
#include "QtGui/QDrag"
#include "QtGui/QDragEnterEvent"
#include "QtGui/QDragLeaveEvent"
#include "QtGui/QDragMoveEvent"
#include "QtGui/QDropEvent"
#include "QtGui/QEnterEvent"
#include "QtGui/QExposeEvent"
#include "QtGui/QFileOpenEvent"
#include "QtGui/QFocusEvent"
#include "QtGui/QFont"
#include "QtGui/QFontDatabase"
#include "QtGui/QFontInfo"
#include "QtGui/QFontMetrics"
#include "QtGui/QFontMetricsF"
#include "QtGui/QGenericMatrix"
#include "QtGui/QGenericPlugin"
#include "QtGui/QGenericPluginFactory"
#include "QtGui/QGlyphRun"
#include "QtGui/QGradient"
#include "QtGui/QGradientStop"
#include "QtGui/QGradientStops"
#include "QtGui/QGuiApplication"
#include "QtGui/QHelpEvent"
#include "QtGui/QHideEvent"
#include "QtGui/QHoverEvent"
#include "QtGui/QIcon"
#include "QtGui/QIconDragEvent"
#include "QtGui/QIconEngine"
#include "QtGui/QIconEnginePlugin"
#include "QtGui/QIconEngineV2"
#include "QtGui/QImage"
#include "QtGui/QImageCleanupFunction"
#include "QtGui/QImageIOHandler"
#include "QtGui/QImageIOPlugin"
#include "QtGui/QImageReader"
#include "QtGui/QImageTextKeyLang"
#include "QtGui/QImageWriter"
#include "QtGui/QInputEvent"
#include "QtGui/QInputMethod"
#include "QtGui/QInputMethodEvent"
#include "QtGui/QInputMethodQueryEvent"
#include "QtGui/QIntValidator"
#include "QtGui/QKeyEvent"
#include "QtGui/QKeySequence"
#include "QtGui/QLinearGradient"
// #include "QtGui/QList"  //  clash with QList
#include "QtGui/QMatrix"
#include "QtGui/QMatrix2x2"
#include "QtGui/QMatrix2x3"
#include "QtGui/QMatrix2x4"
#include "QtGui/QMatrix3x2"
#include "QtGui/QMatrix3x3"
#include "QtGui/QMatrix3x4"
#include "QtGui/QMatrix4x2"
#include "QtGui/QMatrix4x3"
#include "QtGui/QMatrix4x4"
#include "QtGui/QMouseEvent"
#include "QtGui/QMoveEvent"
#include "QtGui/QMovie"
#include "QtGui/QNativeGestureEvent"
#include "QtGui/QOffscreenSurface"
#if 0 //  we don't want to support this ..
#include "QtGui/QOpenGLBuffer"
#include "QtGui/QOpenGLContext"
#include "QtGui/QOpenGLContextGroup"
#include "QtGui/QOpenGLDebugLogger"
#include "QtGui/QOpenGLDebugMessage"
#include "QtGui/QOpenGLExtraFunctions"
#include "QtGui/QOpenGLExtraFunctionsPrivate"
#include "QtGui/QOpenGLFramebufferObject"
#include "QtGui/QOpenGLFramebufferObjectFormat"
#include "QtGui/QOpenGLFunctions"
#include "QtGui/QOpenGLFunctions_1_0"
#include "QtGui/QOpenGLFunctions_1_1"
#include "QtGui/QOpenGLFunctions_1_2"
#include "QtGui/QOpenGLFunctions_1_3"
#include "QtGui/QOpenGLFunctions_1_4"
#include "QtGui/QOpenGLFunctions_1_5"
#include "QtGui/QOpenGLFunctions_2_0"
#include "QtGui/QOpenGLFunctions_2_1"
#include "QtGui/QOpenGLFunctions_3_0"
#include "QtGui/QOpenGLFunctions_3_1"
#include "QtGui/QOpenGLFunctions_3_2_Compatibility"
#include "QtGui/QOpenGLFunctions_3_2_Core"
#include "QtGui/QOpenGLFunctions_3_3_Compatibility"
#include "QtGui/QOpenGLFunctions_3_3_Core"
#include "QtGui/QOpenGLFunctions_4_0_Compatibility"
#include "QtGui/QOpenGLFunctions_4_0_Core"
#include "QtGui/QOpenGLFunctions_4_1_Compatibility"
#include "QtGui/QOpenGLFunctions_4_1_Core"
#include "QtGui/QOpenGLFunctions_4_2_Compatibility"
#include "QtGui/QOpenGLFunctions_4_2_Core"
#include "QtGui/QOpenGLFunctions_4_3_Compatibility"
#include "QtGui/QOpenGLFunctions_4_3_Core"
#include "QtGui/QOpenGLFunctions_4_4_Compatibility"
#include "QtGui/QOpenGLFunctions_4_4_Core"
#include "QtGui/QOpenGLFunctions_4_5_Compatibility"
#include "QtGui/QOpenGLFunctions_4_5_Core"
#include "QtGui/QOpenGLFunctions_ES2"
#include "QtGui/QOpenGLFunctionsPrivate"
#include "QtGui/QOpenGLPaintDevice"
#include "QtGui/QOpenGLPixelTransferOptions"
#include "QtGui/QOpenGLShader"
#include "QtGui/QOpenGLShaderProgram"
#include "QtGui/QOpenGLTexture"
#include "QtGui/QOpenGLTextureBlitter"
#include "QtGui/QOpenGLTimeMonitor"
#include "QtGui/QOpenGLTimerQuery"
#include "QtGui/QOpenGLVersionFunctions"
#include "QtGui/QOpenGLVersionProfile"
#include "QtGui/QOpenGLVertexArrayObject"
#include "QtGui/QOpenGLWindow"
#endif
#include "QtGui/QPagedPaintDevice"
#include "QtGui/QPageLayout"
#include "QtGui/QPageSize"
#include "QtGui/QPaintDevice"
#include "QtGui/QPaintDeviceWindow"
#include "QtGui/QPaintEngine"
#include "QtGui/QPaintEngineState"
#include "QtGui/QPainter"
#include "QtGui/QPainterPath"
#include "QtGui/QPainterPathStroker"
#include "QtGui/QPaintEvent"
#include "QtGui/QPalette"
#include "QtGui/QPdfWriter"
#include "QtGui/QPen"
#include "QtGui/QPicture"
#include "QtGui/QPictureFormatPlugin"
#include "QtGui/QPictureIO"
#include "QtGui/QPixelFormat"
#include "QtGui/QPixmap"
#include "QtGui/QPixmapCache"
#include "QtGui/QPlatformSurfaceEvent"
#include "QtGui/QPointingDeviceUniqueId"
#include "QtGui/QPolygon"
#include "QtGui/QPolygonF"
#include "QtGui/QQuaternion"
#include "QtGui/QRadialGradient"
#include "QtGui/QRasterWindow"
#include "QtGui/QRawFont"
#include "QtGui/QRegExpValidator"
#include "QtGui/QRegion"
#include "QtGui/QRegularExpressionValidator"
#include "QtGui/QResizeEvent"
#include "QtGui/QRgb"
#include "QtGui/QRgba64"
#include "QtGui/QScreen"
#include "QtGui/QScreenOrientationChangeEvent"
#include "QtGui/QScrollEvent"
#include "QtGui/QScrollPrepareEvent"
#include "QtGui/QSessionManager"
#include "QtGui/QShortcutEvent"
#include "QtGui/QShowEvent"
#include "QtGui/QStandardItem"
#include "QtGui/QStandardItemModel"
#include "QtGui/QStaticText"
#include "QtGui/QStatusTipEvent"
#include "QtGui/QStyleHints"
#include "QtGui/QSurface"
#include "QtGui/QSurfaceFormat"
#include "QtGui/QSyntaxHighlighter"
#include "QtGui/QTabletEvent"
#include "QtGui/QtEvents"
#include "QtGui/QTextBlock"
#include "QtGui/QTextBlockFormat"
#include "QtGui/QTextBlockGroup"
#include "QtGui/QTextBlockUserData"
#include "QtGui/QTextCharFormat"
#include "QtGui/QTextCursor"
#include "QtGui/QTextDocument"
#include "QtGui/QTextDocumentFragment"
#include "QtGui/QTextDocumentWriter"
#include "QtGui/QTextFormat"
#include "QtGui/QTextFragment"
#include "QtGui/QTextFrame"
#include "QtGui/QTextFrameFormat"
#include "QtGui/QTextFrameLayoutData"
#include "QtGui/QTextImageFormat"
#include "QtGui/QTextInlineObject"
#include "QtGui/QTextItem"
#include "QtGui/QTextLayout"
#include "QtGui/QTextLength"
#include "QtGui/QTextLine"
#include "QtGui/QTextList"
#include "QtGui/QTextListFormat"
#include "QtGui/QTextObject"
#include "QtGui/QTextObjectInterface"
#include "QtGui/QTextOption"
#include "QtGui/QTextTable"
#include "QtGui/QTextTableCell"
#include "QtGui/QTextTableCellFormat"
#include "QtGui/QTextTableFormat"
#include "QtGui/QtGui"
#include "QtGui/QtGuiDepends"
#include "QtGui/QtGuiVersion"
#include "QtGui/QToolBarChangeEvent"
#include "QtGui/QTouchDevice"
#include "QtGui/QTouchEvent"
#include "QtGui/QTransform"
#include "QtGui/QValidator"
#include "QtGui/QVector2D"
#include "QtGui/QVector3D"
#include "QtGui/QVector4D"
#if 0 //  we don't want to support this ..
#include "QtGui/QVulkanDeviceFunctions"
#include "QtGui/QVulkanExtension"
#include "QtGui/QVulkanFunctions"
#include "QtGui/QVulkanInfoVector"
#include "QtGui/QVulkanInstance"
#include "QtGui/QVulkanLayer"
#include "QtGui/QVulkanWindow"
#include "QtGui/QVulkanWindowRenderer"
#endif
#include "QtGui/QWhatsThisClickedEvent"
#include "QtGui/QWheelEvent"
#include "QtGui/QWidgetList"
#include "QtGui/QWidgetMapper"
#include "QtGui/QWidgetSet"
#include "QtGui/QWindow"
#include "QtGui/QWindowList"
#include "QtGui/QWindowStateChangeEvent"
